#
# spec file for package python3-Markdown
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-Markdown
Version:        2.6.2
Release:        4.2
Summary:        Python implementation of Markdown
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            http://pypi.python.org/pypi/Markdown/
Source:         http://pypi.python.org/packages/source/M/Markdown/Markdown-%{version}.tar.gz
BuildRequires:  python3-PyYAML
BuildRequires:  python3-devel
BuildRequires:  python3-nose
BuildRequires:  python3-xml
Requires:       python3-xml
Requires(post):	update-alternatives
Requires(postun):	update-alternatives
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
This is a Python implementation of John Gruber's [Markdown][].
It is almost completely compliant with the reference implementation,
though there are a few known issues. See [Features][] for information
on what exactly is supported and what is not. Additional features are
supported by the [Available Extensions][].

%prep
%setup -q -n Markdown-%{version}
# Fix encoding
find . -type f -not -name py.png -print0 | xargs -0 sed -i "s|\r$||"

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

# update-alternatives
mv %{buildroot}%{_bindir}/markdown_py %{buildroot}%{_bindir}/markdown_py-%{py3_ver}
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
touch %{buildroot}%{_sysconfdir}/alternatives/markdown_py
ln -sf %{_sysconfdir}/alternatives/markdown_py %{buildroot}%{_bindir}/markdown_py

%check
python3 run-tests.py

%post
update-alternatives \
	--install %{_bindir}/markdown_py markdown_py %{_bindir}/markdown_py-%{py3_ver} 30

%postun
if [ $1 -eq 0 ] ; then
	update-alternatives --remove markdown_py %{_bindir}/markdown_py-%{py3_ver}
fi

%files
%defattr(-,root,root,-)
%doc LICENSE.md README.md docs/*
%ghost %{_sysconfdir}/alternatives/markdown_py
%{_bindir}/markdown_py
%{_bindir}/markdown_py-%{py3_ver}
%{python3_sitelib}/Markdown-%{version}-py%{py3_ver}.egg-info
%{python3_sitelib}/markdown

%changelog
* Tue Apr 21 2015 benoit.monin@gmx.fr
- update to version 2.6.2: bugfix release
* Tue Mar 10 2015 benoit.monin@gmx.fr
- update to version 2.6.1: bugfix release
  The (new) yaml option has been removed from the Meta-Data
  Extension as it was buggy
* Fri Feb 20 2015 arun@gmx.de
- specfile:
  * update copyright year
  * fix url
  * removed trailing whitespace
- update to version 2.6:
  * `safe_mode` Deprecated
  * Positional Arguments Deprecated
  * "Shortened" Extension Names Deprecated
  * Extension Configuration as Part of Extension Name Deprecated
  * HeaderId Extension Pending Deprecation
  * The `configs` Keyword is Deprecated
  * Official Support for PyPy
  * YAML Style Meta-Data
  * Table of Contents Extension Refactored
  * Pygments can now be disabled
  * Miscellaneous
* Mon Nov 24 2014 benoit.monin@gmx.fr
- update to version 2.5.2: bugfix release
* Fri Oct  3 2014 benoit.monin@gmx.fr
- update to version 2.5.1: bugfix release
* Tue Sep 16 2014 benoit.monin@gmx.fr
- update to version 2.5:
  * The force_linenos config key on the CodeHilite extension has
    been deprecated.
  * Both safe_mode and the associated html_replacement_text
    keywords will be deprecated in version 2.6.
  * Positional arguments on the markdown.Markdown() function are
    pending deprecation.
  * The builtin extensions did not require the full path to be
    provided. This behavior will be deprecated in version 2.6.
  * The previously documented method of appending the extension
    configs as a string to the extension name will be deprecated in
    version 2.6.
  * The Smarty extension has had a number of additional
    configuration settings added.
  * Named extensions can now point to any module and/or Class on
    your PYTHONPATH.
  * The extension configuration code has been refactored.
  * The command line interface now accepts a --extensions_config
    (or -c).
  * The amonition extension is no longer considered experimental.
  * Various bug fixes have been made.
- add python-PyYAML to BuildRequires: needed for tests
* Thu Jun 26 2014 i@marguerite.su
- fix conflicts with python-Markdown
  * both use update-alternatives
* Wed Jun 25 2014 i@marguerite.su
- update version 2.4.1
  * added nav-tag as block level element
  * pass tuples, not iterable strings to the pattern
  * fix test failure with python 3.1 and 3.2
  * no assertls in python 2.6
  * add smarty to extensions for attr_list test
  * fix issue308 and failure to break out of nest loop
* Mon Feb 17 2014 benoit.monin@gmx.fr
- update to version 2.4:
  * the "force_linenos" config setting of the CodeHilite extension
    has been marked as Deprecated.
  * URLs are no longer percent-encoded.
  * the Smarty Extension has been added, which implements
    SmartyPants.
  * the Table of Contents Extension now supports new permalink
    option for creating Sphinx-style anchor links.
  * it is now possible to enable Markdown formatting inside HTML
    blocks by appending `markdown=1` to opening tag attributes.
  * The code blocks now support emphasizing some of the code lines.
  * Various bug fixes have been made.
- fix CRLF in all files: upstream converted to DOS encoding
* Wed Jan 29 2014 benoit.monin@gmx.fr
- initial python3 package with version 2.3.1
